==> showcase-0.8.0.4-src.zip: content/settings/pref-window.js <==
function windowPrefInit() {
  // Check all enable/disable dependancies
  windowWidthChanged();
  windowHeightChanged();
  windowCustomColorsChanged();
  windowScrollTypeChanged();
}

function windowWidthChanged() {
  var windowWidthComboBox = document.getElementById("windowWidth");
  document.getElementById("windowWidthPercentageLabel").disabled = (windowWidthComboBox.selectedIndex == 2);
  document.getElementById("windowWidthPercentageSymbolLabel").disabled = (windowWidthComboBox.selectedIndex == 2);
  document.getElementById("windowWidthPercentage").disabled = (windowWidthComboBox.selectedIndex == 2);
  document.getElementById("windowWidthModifierLabel").disabled = (windowWidthComboBox.selectedIndex == 2);
  document.getElementById("windowWidthModifierUnitLabel").disabled = (windowWidthComboBox.selectedIndex == 2);
  document.getElementById("windowWidthModifier").disabled = (windowWidthComboBox.selectedIndex == 2);
}

function windowHeightChanged() {
  var windowHeightComboBox = document.getElementById("windowHeight");
  document.getElementById("windowHeightPercentageLabel").disabled = (windowHeightComboBox.selectedIndex == 2);
  document.getElementById("windowHeightPercentageSymbolLabel").disabled = (windowHeightComboBox.selectedIndex == 2);
  document.getElementById("windowHeightPercentage").disabled = (windowHeightComboBox.selectedIndex == 2);
  document.getElementById("windowHeightModifierLabel").disabled = (windowHeightComboBox.selectedIndex == 2);
  document.getElementById("windowHeightModifierUnitLabel").disabled = (windowHeightComboBox.selectedIndex == 2);
  document.getElementById("windowHeightModifier").disabled = (windowHeightComboBox.selectedIndex == 2);
}

function windowCustomColorsChanged() {
  var windowCustomColorsCheckbox = document.getElementById("windowCustomColors");
  document.getElementById("windowCustomBackgroundColorLabel").disabled = !windowCustomColorsCheckbox.checked;
  document.getElementById("windowCustomBackgroundColor").disabled = !windowCustomColorsCheckbox.checked;
}

function windowScrollTypeChanged() {
  var windowScrollTypeComboBox = document.getElementById("windowScrollType");
  document.getElementById("windowThumbnailPreferredMinimumSizeLabel").disabled = (windowScrollTypeComboBox.selectedIndex == 0);
  document.getElementById("windowThumbnailPreferredMinimumSizePixelsLabel").disabled = (windowScrollTypeComboBox.selectedIndex == 0);
  document.getElementById("windowThumbnailPreferredMinimumSize").disabled = (windowScrollTypeComboBox.selectedIndex == 0);
}

==> showcase-0.9.2-src.zip: content/settings/pref-window.js <==
function windowPrefInit() {
  // Check all enable/disable dependancies
  windowWidthChanged();
  windowHeightChanged();
  windowCustomColorsChanged();
  windowScrollTypeChanged();
}

function windowWidthChanged() {
  var windowWidthComboBox = document.getElementById("windowWidth");
  document.getElementById("windowWidthPercentageLabel").disabled = (windowWidthComboBox.selectedIndex == 2);
  document.getElementById("windowWidthPercentageSymbolLabel").disabled = (windowWidthComboBox.selectedIndex == 2);
  document.getElementById("windowWidthPercentage").disabled = (windowWidthComboBox.selectedIndex == 2);
  document.getElementById("windowWidthModifierLabel").disabled = (windowWidthComboBox.selectedIndex == 2);
  document.getElementById("windowWidthModifierUnitLabel").disabled = (windowWidthComboBox.selectedIndex == 2);
  document.getElementById("windowWidthModifier").disabled = (windowWidthComboBox.selectedIndex == 2);
}

function windowHeightChanged() {
  var windowHeightComboBox = document.getElementById("windowHeight");
  document.getElementById("windowHeightPercentageLabel").disabled = (windowHeightComboBox.selectedIndex == 2);
  document.getElementById("windowHeightPercentageSymbolLabel").disabled = (windowHeightComboBox.selectedIndex == 2);
  document.getElementById("windowHeightPercentage").disabled = (windowHeightComboBox.selectedIndex == 2);
  document.getElementById("windowHeightModifierLabel").disabled = (windowHeightComboBox.selectedIndex == 2);
  document.getElementById("windowHeightModifierUnitLabel").disabled = (windowHeightComboBox.selectedIndex == 2);
  document.getElementById("windowHeightModifier").disabled = (windowHeightComboBox.selectedIndex == 2);
}

function windowCustomColorsChanged() {
  var windowCustomColorsCheckbox = document.getElementById("windowCustomColors");
  document.getElementById("windowCustomBackgroundColorLabel").disabled = !windowCustomColorsCheckbox.checked;
  document.getElementById("windowCustomBackgroundColor").disabled = !windowCustomColorsCheckbox.checked;
}

function windowScrollTypeChanged() {
  var windowScrollTypeComboBox = document.getElementById("windowScrollType");
  document.getElementById("windowThumbnailPreferredMinimumSizeLabel").disabled = (windowScrollTypeComboBox.selectedIndex == 0);
  document.getElementById("windowThumbnailPreferredMinimumSizePixelsLabel").disabled = (windowScrollTypeComboBox.selectedIndex == 0);
  document.getElementById("windowThumbnailPreferredMinimumSize").disabled = (windowScrollTypeComboBox.selectedIndex == 0);
  document.getElementById("windowAlwaysShowScrollbar").disabled = (windowScrollTypeComboBox.selectedIndex == 0);
}
